#!/usr/bin/env python
"""Utilities for coms.

Author: Ian Watson (igw)
Date: 12 Jul 2014
"""

#import sys
#import os
#import time


################################################################################
def chrs2ints(chars):
    """Convert string of chars to list of ints.
    OLD SYTLE - Use bytes().
    """
    nums = [ ord(c) for c in chars ]
    return nums


def ints2chrs(nums):
    """Convert tuple/list of ints to string of chars.
    OLD SYTLE - Use bytes().
    """
    chrs = "".join( [ chr(n) for n in nums ] )
    return chrs


def ints2hexs(nums):
    """Convert tuple/list of ints to list of hex strings.
    OLD SYTLE - Use bytes().
    """
    hexs = [ hex(n) for n in nums ]
    return hexs


def value2ints(ints_hex_str, asList = False):
    """Convert given item or items to an int or a list of ints.
    - ints_hex_str - Given an int, a list of 1 int, or 2 char hex string (with optional leading '0x'), is it converted to an int or if required a list of int's. A list of ints or hex string longer than 2 chars will ALWAYS return a list of ints.
    - asList - forces a list, if only one item given.
    """
    if type(ints_hex_str) == str:
        ints_hex_str = ints_hex_str.replace("0x", "")
        vals = []
        for n in range(0, len(ints_hex_str), 2):
            vals.append( int(ints_hex_str[n:n+2], 16) )
    elif isinstance(ints_hex_str, int):
        vals = [ints_hex_str]
    else:
        vals = ints_hex_str
    
    if len(vals) == 1 and not asList:
        vals = vals[0]
    
    return vals


################################################################################
def dec2bin(num, ndigits = 8):
    """Convert integer 'num' to binary string of 'ndigits' chars length.
    Pads with leading '0' to required length.
    Does not truncate if results has more than 'ndigits'. No leading '0b'.
    dec2bin(9, 8) = '00001001'
    """
    return bin(num)[2:].zfill(ndigits)

def dec2hex(num, ndigits = 2):
    """Convert integer 'num' to hexadecimal string of 'ndigits' chars length.
    Pads with leading '0' to required length.
    Does not truncate if results has more than 'ndigits'. No leading '0x'.
    """
    # Convert to 0xABCDL format. Remove leading 0x. Will have trailing L when 'num' is a long.
    s = hex(num)[2:]
    # Remove trail L when 'num' type long, NB. int maximum machine dependent, 2^32 or 2^64.
    s = s.rstrip("L").zfill(ndigits)
    return s

def neatBinStr(binStr, nbits = 4, sep = "-"):
    """Group a binary string into neat group of n-bits, usually nibbles of 4.
    This aids human reading of long bit sequences.
    Ex.,
        '0011110010011000'
    is returned as
        '0011-1100-1001-1000'.
    """
    rem = len(binStr) % nbits
    newStr = binStr[0:rem]
    for idx in range(rem, len(binStr), nbits):
        newStr += sep + binStr[idx:idx+nbits]
    #return '0b' + newStr.lstrip(sep)
    return newStr.lstrip(sep)


################################################################################
# def sendBytes(sp, values):
#     """Send list ints to serial port.
#     List of int8's. Could be string, but list easier for manipulating number.
#     - sp - pyserial serial port.
#     - values - list of ints.
#     """
#     sp.write( ints2chrs(values) )
#     #if type(values) == list:
#     #    values = ints2chrs(values)
#     #sp.write(values)

# def getBytes(sp, n = None):
#     """Return list of int8's from serial port.
#     - sp - pyserial serial port.
#     - values - list of ints.
#     """
#     time.sleep(0.002)
#     if n:
#         buf = sp.in_waiting
#         count = 0
#         while buf < n:
#             time.sleep(0.002)
#             buf = sp.in_waiting
#             count += 1
#             if count > 2500:
#                 nums = sp.read(buf)
#                 break
#     else:
#         print("PLEASE GIVE NUMBER OF BYTES TO READ.")
#         buf = sp.in_waiting
#         while buf < 1:
#             time.sleep(0.002)
#             buf = sp.in_waiting
#         n = buf
#         
#     if n != buf:
#         print("ISSUE BUFFER HAS DIFFERENT NUMBER THAN REQUESTED %d != %d" % ( n, buf ))
#     
#     nums = sp.read(n)
#     return nums
