#!/usr/bin/env python
"""Kate test rig setup.

Defines for each piece of equipment and hardwire routing and switching.

Author: Ian Watson (igw)
Date: 12 Jan 2014
"""

# Load modules.
#import testutils
import PSU_PL303QMDP
#import MM_K2110
#import MM_K2015
#import robotrly
import AWG_DG1000Z
import AWG_DG1000
import DS_DS1000Z
import DS_DS1000E
#import SA_HP8596

    
################################################################################
# Which hardware rig.
RIG_EN = 0
RIG_IGW = 1
#RIG = RIG_EN
RIG = RIG_IGW

# Kate USBISS port.
if RIG == RIG_EN:
    USBISS_PORT = "COM32"
else:
    USBISS_PORT = "COM5"

# GPIB Controller.
if RIG == RIG_EN:
    GPIBcontroller = "prologix"
else:
    GPIBcontroller = "visa"
# Prologix coms port.
GPIBcontrollerPort = "COM33"

# PSU
if RIG == RIG_EN:
    PSU_RESOURCE = "ASRL23"
else:
    PSU_RESOURCE = "ASRL16"
PSU_CH = PSU_PL303QMDP.CH_MASTER

# Multimeter supply current. Keithley 2110 or 2015.
if RIG == RIG_EN:
    MM_ISUP_RESOURCE = "USBInstK2110"
else:
    MM_ISUP_RESOURCE = "GPIB::8"

# Multimeter voltage mux. Keithley 2015.
if RIG == RIG_EN:
    MM_VMEAS_RESOURCE = "GPIB::10"
else:
    MM_VMEAS_RESOURCE = "GPIB::9"

# Volt switch measure multiplexer.
if RIG == RIG_EN:
    MUX_VMEAS_RESOURCE = "COM20"
else:
    MUX_VMEAS_RESOURCE = "COM21"
MUX_VMEAS_CH_VMON1V8 = 1
MUX_VMEAS_CH_VMON2V7 = 2
MUX_VMEAS_CH_VBG = 3

# SMA multiplexer.
MUX_SMA_RESOURCE = "COM19"
MUX_SMA_CH_UPCKOUT = 1
MUX_SMA_CH_I2SCKOUT = 2

# Arbitary gen 1 + frequency measure. Rigol DG1000Z.
if RIG == RIG_EN:
    AWG_GEN_A_TYPE = "AWG" # Force AWG here.
    AWG_GEN_A_RESOURCE = "USBInstDG1000Z"
    AWG_GEN_A_CH_RXIN = AWG_DG1000Z.CH1
    AWG_GEN_A_CH_TXMON = AWG_DG1000Z.CH2
else:
    AWG_GEN_A_TYPE = "AWG"
    #AWG_GEN_A_TYPE = "RF"
    if AWG_GEN_A_TYPE == "AWG":
        AWG_GEN_A_RESOURCE = "USBInstDG1022U"
        AWG_GEN_A_CH_RXIN = AWG_DG1000.CH1
        AWG_GEN_A_CH_TXMON = AWG_DG1000.CH2
    else:
        AWG_GEN_A_RESOURCE = "GPIB::5"
        AWG_GEN_A_CH_RXIN = AWG_DG1000.CH1
        AWG_GEN_A_CH_TXMON = AWG_DG1000.CH2
# 50ohm PAD (dB) on each channel output.
AWG_GEN_A_CH_PAD_RXIN = 0 # Use 0 for RF. Use 8 for AWG. 6 10 12
AWG_GEN_A_CH_PAD_TXMON = 8

# Arbitary gen 2. Rigol DG1000Z.
if RIG == RIG_EN:
    #AWG_GEN_B_RESOURCE = "USBInstDG1000Z_2"
    # Temp while instrument being used.
    AWG_GEN_B_RESOURCE = "USBInstDG1000Z"
    AWG_GEN_B_CH_TXD = AWG_DG1000Z.CH1
    AWG_GEN_B_CH_TXREF = AWG_DG1000Z.CH2
else:
    AWG_GEN_B_RESOURCE = "USBInstDG1022U"
    AWG_GEN_B_CH_TXD = AWG_DG1000.CH1
    AWG_GEN_B_CH_TXREF = AWG_DG1000.CH2

# Dig scope. Rigol DS1104Z.
if RIG == RIG_EN:
    DS_RESOURCE = "USBInstDS1000Z"
    DS_CHAN_RXI = DS_DS1000Z.CHAN1
    DS_CHAN_RXQ = DS_DS1000Z.CHAN2
    DS_CHAN_UPCKOUT = DS_DS1000Z.CHAN3
else:
    DS_RESOURCE = "USBInstDS1000E"
    DS_CHAN_RXI = DS_DS1000E.CHAN1
    DS_CHAN_RXQ = DS_DS1000E.CHAN2

# SpecAna.
SA_RESOURCE = "GPIB::18"
# SpecAna protective 50ohm PAD (dB). This is to protect against maximum 1.8Vpk (VDD of 3.6/2) or 10*log10(Vpk^2/0.002/50) = 15.1dBm.
# See KateIC.txMatchingLoss(Rload, currentDrive)
SA_PROTECTION_PAD = 0 # 12 HACK try with out atten for better noise floor.
# TX maximum level.
TX_MAX_VPK = 1.3
# INFO: So signal measured in 50ohm dBm. Vpk = sqrt( 0.002*50*10^(dBm50R/10) ). dBm50R = 10*log10( Vpk^2/0.002/50 ).
# dBm50R is converted to dBVpk by, dBV = dBm50R - 10.
# 0dBm = 0.316Vpk = -10dBV. 10dBm = 1Vpk = 0dBV.
SA_dBm50R_TO_dBV = -10

# TX modulation output to test mux. Set this to 0 off, or 7 to output to mux.
DEBUG_HACK_TXREFDB = 0
